@@ -149,9 +149,10 @@ class LocalMachine(BaseMachine):
         self._as_user_stack = []
 
     if IS_WIN32:
-        _EXTENSIONS = [""] + env.get("PATHEXT", ":.exe:.bat").lower().split(
-            os.path.pathsep
-        )
+        _EXTENSIONS = [
+            "",
+            *env.get("PATHEXT", ":.exe:.bat").lower().split(os.path.pathsep),
+        ]
 
         @classmethod
         def _which(cls, progname):
@@ -217,8 +218,7 @@ class LocalMachine(BaseMachine):
             self[cmd]
         except CommandNotFound:
             return False
-        else:
-            return True
+        return True
 
     def __getitem__(self, cmd):
         """Returns a `Command` object representing the given program. ``cmd`` can be a string or
@@ -259,8 +259,10 @@ class LocalMachine(BaseMachine):
             kwargs["start_new_session"] = True
 
         if IS_WIN32 and "startupinfo" not in kwargs and stdin not in (sys.stdin, None):
+            # pylint: disable-next=used-before-assignment
             subsystem = get_pe_subsystem(str(executable))
 
+            # pylint: disable-next=used-before-assignment
             if subsystem == IMAGE_SUBSYSTEM_WINDOWS_CUI:
                 # don't open a new console
                 sui = subprocess.STARTUPINFO()
@@ -426,12 +428,12 @@ class LocalMachine(BaseMachine):
         else:
             if username is None:
                 self._as_user_stack.append(
-                    lambda argv: (["sudo"] + list(argv), self.which("sudo"))
+                    lambda argv: (["sudo", *list(argv)], self.which("sudo"))
                 )
             else:
                 self._as_user_stack.append(
                     lambda argv: (
-                        ["sudo", "-u", username] + list(argv),
+                        ["sudo", "-u", username, *list(argv)],
                         self.which("sudo"),
                     )
                 )
